@@ -247,6 +247,16 @@ def get_array_hash(d):
     return h.hexdigest()
 
 
+def chown(path, username, group=None, recursive=True):
+    if not group:
+        group = username
+    if recursive:
+        r_str = '-R '
+    else:
+        r_str = ''
+    os.system('chown {0}{1}:{2} "{3}"'.format(r_str, username, group, path))
+
+
 class Logger:
     def __init__(self, to_console=True, file=None):
         self._to_console = to_console
